Crate rt_write_lock

Crate rt_write_lock 

Structs

ReadGuard
Reader
WriteGuard
The data should always be replaced completely. Incremental updates can lead to the reader seeing inconsistent data, as the data structure uses two copies of the data internally and alternates between writing to both of them. The copies will start to diverge when doing changes instead of replacing it.
Writer