pub struct WriteGuard<'a, T> { /* private fields */ }Expand description
The data should always be replaced completely. Incremental updates can lead to the reader seeing inconsistent data, as the data structure uses two copies of the data internally and alternates between writing to both of them. The copies will start to diverge when doing changes instead of replacing it.
I still offer DerefMut instead of just taking a new T, because this allows reusing allocations inside of T instead of dropping and reallocing. This is important for realtime usecases.